<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt </source>
        <translation>использует Qt </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Благодарности</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Это лёгкое и мощное приложение, написанное на Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="109"/>
        <source>Licensed under the </source>
        <translation>Лицензировано по </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Помощь проекту</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Автор &amp;copy; 2009-2013, Артём &apos;DOOMer&apos; Галичкин</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>Чем можно помочь?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>кроссплатформенное приложение для быстрого создания снимков вашего рабочего стола.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Если хотите, вы можете присоединиться к нам и помочь. Это приглашение, если вам понравилось приложение.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Перевести ScreenGrab на другие языки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>Выразить пожелания для следующих выпусков</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>Сообщать об ошибках в работе приложения</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Баг-трекер</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="141"/>
        <source>Translate:</source>
        <translation>Переводы:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Бразильская Португальская локализация</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>Marcio Moraes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source> Ukrainian translation</source>
        <translation> Украинская локализация</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="147"/>
        <source>Gennadi Motsyo</source>
        <translation>Геннадий Моцьо</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source> Spanish translation</source>
        <translation> Испанская локализация</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="150"/>
        <source>Burjans L García D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="152"/>
        <source> Italian translation</source>
        <translation> Итальянская локализация</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="156"/>
        <source>Testing:</source>
        <translation>Тестирование:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Поддержка работы на двух мониторах и другие тесты в Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>Dual monitor support in Linux</source>
        <translation>Поддержка двух мониторов в Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32-версии [Windows XP и 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>Ранние win32-версии [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="162"/>
        <source>win32-build [Windows 7]</source>
        <translation>win32-версии [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="282"/>
        <source>Select directory</source>
        <translation>Выбрать каталог</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="193"/>
        <location filename="../src/core/ui/configwidget.cpp" line="294"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="192"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>Каталог %1 не существует. Вы хотите создать его?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="293"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Сбросить настройки на настройки по умолчанию?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="351"/>
        <source>Example: </source>
        <translation>Пример: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="406"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Эта комбинация уже используется в ScreenGrab! Выберите другую.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="424"/>
        <source>This key is not supported on your system!</source>
        <translation>Эта комбинация не поддерживается вашей системой!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="444"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="431"/>
        <source>Saved</source>
        <translation>Сохранено</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="453"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Имя сохранённого файла скопировано в буфер обмена</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="481"/>
        <source>Copied</source>
        <translation>Скопировано</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="431"/>
        <source>Saved to </source>
        <translation>Сохранено в </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="58"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>кроссплатформенное приложение для быстрого создания снимков вашего рабочего стола.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="62"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Сделать снимок всего экрана</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>Take a screenshot of the active window</source>
        <translation>Сделать снимок активного окна</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Сделать снимок выбранной области экрана</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Run the application with a hidden main window</source>
        <translation>Запустить приложение со скрытым главным окном</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="459"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Путь к сохранённому файлу скопирован в буфер обмена</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="481"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Скриншот скопирован в буфер обмена</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
        <source>Screenshot </source>
        <translation>Скриншот </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Двойной щелчок откроет снимок экрана во внешнем просмотрщике</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
        <source>Hide</source>
        <translation>Скрыть окно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Ни одного</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
        <source>Show</source>
        <translation>Показать окно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
        <source>%1 Files</source>
        <translation>%1 Файлы</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
        <source>Save As...</source>
        <translation>Сохранить как...</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Тип скриншота</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Весь экран</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Область экрана</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Последняя выбранная область</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Задержка:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Приблизить область вокруг мыши</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Без декораций окна</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Включить указатель мыши</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Задержка в секундах перед получением скриншота</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="170"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Удерживая клавишу мыши и перемещая курсор, нарисуйте прямоугольник.
Затем щёлкните два раза или нажмите Ввод, чтобы получить снимок экрана.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="202"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 пикс </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Внешний редактор</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Открыть в ...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="128"/>
        <source>About Qt</source>
        <translation>О библиотеке Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="154"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="628"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Формат скриншотов по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Вставка даты и времени в имя сохраняемого файла</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Добавить текущую дату и время к имени файла</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Австосохранение скриншота</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Сохранять первый скриншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Качество изображения</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Качество изображения (1 - меньший размер файла, 100 - лучшее качество)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Разрешить запускать несколько копий ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Использовать внешний просмотрщик</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="449"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Показывать ScreenGrab в системном трее</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="534"/>
        <source>Minimize to tray on click close button</source>
        <translation>Сворачивает в трей при закрытии основного окна</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="537"/>
        <source>Minimize to tray when closing</source>
        <translation>Сворачивать в трей при закрытии</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="576"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="586"/>
        <source>Global shortcuts</source>
        <translation>Глобальные комбинации</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="598"/>
        <source>Active window</source>
        <translation>Активное окно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="603"/>
        <source>Area select</source>
        <translation>Выбранная область</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="609"/>
        <source>Local shortcuts</source>
        <translation>Внутренние комбинации</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="613"/>
        <source>New screen</source>
        <translation>Новый скриншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="618"/>
        <source>Save screen</source>
        <translation>Сохранить скриншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="623"/>
        <source>Copy screen</source>
        <translation>Копировать скриншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="633"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="656"/>
        <source>Not defined</source>
        <translation>Не определена</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Основные</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Системный трей</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Исходный каталог для сохраняемых файлов</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Обзор файловой системы</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Имя файла по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Копировать имя файла в буфер обмена при сохранении</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>Не копировать</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Копировать только имя файла</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Копировать полный путь файла</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Если не отмечено, по щелчку правой кнопкой выделенная область
будет увеличена, чтобы включить внешние видимые границы</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>По щелчку правой кнопкой уменьшать выбранную область до видимых граней внутри оной</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Каталог для сохранения по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Файл по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Шаблон: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Пример: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Автоматическое сохранение скриншотов при их получении</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="458"/>
        <source>Tray messages:</source>
        <translation>Всплывающие уведомления:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="471"/>
        <source>Tray messages display mode</source>
        <translation>Режим отображения всплывающих уведомлений</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="475"/>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="480"/>
        <source>Tray mode</source>
        <translation>Если свёрнуто</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="485"/>
        <source>Always</source>
        <translation>Всегда</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Комбинации клавиш</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Разрешить несколько копий ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Открывать во внешнем просмотрщике по двойному щелчку</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="581"/>
        <source>Shortcut</source>
        <translation>Клавиши</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="593"/>
        <source>Full screen</source>
        <translation>Весь экран</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="638"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="649"/>
        <source>Selected shortcut:</source>
        <translation>Выбранная комбинация:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="497"/>
        <source>Time of display tray messages</source>
        <translation>Время отображения всплывающих уведомлений</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="513"/>
        <source>Time to display tray messages</source>
        <translation>Время отображения всплывающих уведомлений</translation>
    </message>
</context>
</TS>
